using System;
using Microsoft.SPOT;


/// <summary>
/// The command GETAD is used to read the value of an A/D channel
/// 
/// Usage: GETAD [channel]
///     - channel is an integer value between 1 and 4
///     
/// Returns: an integer with the value of the A/D channel. The returned
/// value is between 0 and 255.
/// 
/// </summary>
class CmdGetAD : Command
{

    /// <summary>
    /// class constructor
    /// </summary>
    public CmdGetAD()
    {
        keyword = "GETAD";
        addParameter("channel", parameterType.INTEGER, 1, 4); 
    }



    /// <summary>
    /// executeCommand() will execute the Cmd... class on the K8000 card
    /// </summary>
    /// <returns>A boolean to indicate if the execution succeeded</returns>
    public override string executeCommand()
    {
        int channel = getIntParameter("channel");

        if (channel > -1)
        {
            K8000.readAllAD();
            int da = K8000.AD[channel];
            return "" + da;
        }
        else
        {
            throw new Exception ("invalid channel");
        }
    }
}

