using System;
using Microsoft.SPOT;


/// <summary>
/// The command SETDA is used to set the value of the D/A convertor
/// 
/// Usage: SETDA [channel] [value]
///     - channel the number of the D/A channel: it should always be 1.
///     - value is the value to send to the D/A output. It can be a number between 0 and 255.
///     
/// </summary>
class CmdSetDA : Command
{

    /// <summary>
    /// class constructor
    /// </summary>
    public CmdSetDA()
    {
        keyword = "SETDA";
        addParameter("channel", parameterType.INTEGER, 1, 1);
        addParameter("value", parameterType.INTEGER, 0, 255);
    }



    /// <summary>
    /// executeCommand() will execute the Cmd... class on the K8000 card
    /// </summary>
    /// <returns>A boolean to indicate if the execution succeeded</returns>
    public override string executeCommand()
    {
        int channelToChange = getIntParameter("channel");
        int valueToSet = getIntParameter("value");

        if (channelToChange > -1 && valueToSet > -1)
            K8000.outputDAchannel(channelToChange, valueToSet);

        return "";
    }
}

