using System;
using Microsoft.SPOT;


/// <summary>
/// The command SETIO is used to set a certain I/O channel
/// 
/// Usage: SETIO [channel]
///     - channel is an integer value between 1 and 16
///     
/// Returns: a String with the value of each I/O channel. The
/// String contains 16 characters (Example: 0000000000000000)
/// </summary>
class CmdSetIO : Command
{

    /// <summary>
    /// class constructor
    /// </summary>
    public CmdSetIO()
    {
        keyword = "SETIO";

        // add all the parameters for this object
        addParameter("channel", parameterType.INTEGER, 1, 16);
    }



    /// <summary>
    /// executeCommand() will execute the Cmd... class on the K8000 card
    /// </summary>
    /// <returns>A boolean to indicate if the execution succeeded</returns>
    public override string executeCommand()
    {
        int channelToSet = getIntParameter("channel");
        if (channelToSet != -1) K8000.setIOchannel(channelToSet);
        return K8000.getIOstr();

    }
}

